==> scx-socket-0.0.7-sources.jar: cool/scx/socket/FrameCreator.java <==
package cool.scx.socket;

import java.util.concurrent.atomic.AtomicLong;

import static cool.scx.socket.ScxSocketFrameType.*;

public final class FrameCreator {

    public static final ScxSocketFrame PING_FRAME = createPingFrame();
    public static final ScxSocketFrame PONG_FRAME = createPongFrame();
    private final AtomicLong seqID;

    public FrameCreator() {
        this.seqID = new AtomicLong(0);
    }

    private static ScxSocketFrame createPingFrame() {
        var pingFrame = new ScxSocketFrame();
        pingFrame.type = PING;
        return pingFrame;
    }

    private static ScxSocketFrame createPongFrame() {
        var pongFrame = new ScxSocketFrame();
        pongFrame.type = PONG;
        return pongFrame;
    }

    public static ScxSocketFrame createAckFrame(long ack_id) {
        var ackFrame = new ScxSocketFrame();
        ackFrame.type = ACK;
        ackFrame.ack_id = ack_id;
        return ackFrame;
    }

    public static ScxSocketFrame createAckFrame(long ack_id, String payload) {
        var ackFrame = createAckFrame(ack_id);
        ackFrame.payload = payload;
        return ackFrame;
    }

    private ScxSocketFrame createBaseFrame(String content, SendOptions options) {
        var baseFrame = new ScxSocketFrame();
        baseFrame.seq_id = this.seqID.getAndIncrement();
        baseFrame.now = System.currentTimeMillis();
        baseFrame.need_ack = options.getNeedAck();
        baseFrame.payload = content;
        return baseFrame;
    }

    public ScxSocketFrame createMessageFrame(String content, SendOptions options) {
        var messageFrame = createBaseFrame(content, options);
        messageFrame.type = MESSAGE;
        return messageFrame;
    }

    public ScxSocketFrame createEventFrame(String eventName, String payload, SendOptions options) {
        var eventFrame = createMessageFrame(payload, options);
        eventFrame.event_name = eventName;
        return eventFrame;
    }

    public ScxSocketFrame createRequestFrame(String eventName, String payload, SendOptions options) {
        var requestFrame = createEventFrame(eventName, payload, options);
        requestFrame.need_response = true;
        return requestFrame;
    }

    public ScxSocketFrame createResponseFrame(long ack_id, String payload, SendOptions options) {
        var responseFrame = createBaseFrame(payload, options);
        responseFrame.type = RESPONSE;
        responseFrame.ack_id = ack_id;
        return responseFrame;
    }

}

==> scx-socket-0.1.5-sources.jar: cool/scx/socket/FrameCreator.java <==
package cool.scx.socket;

import java.util.concurrent.atomic.AtomicLong;

import static cool.scx.socket.ScxSocketFrame.Type.*;

public final class FrameCreator {

    public static final ScxSocketFrame PING_FRAME = createPingFrame();
    public static final ScxSocketFrame PONG_FRAME = createPongFrame();
    private final AtomicLong seqID;

    public FrameCreator() {
        this.seqID = new AtomicLong(0);
    }

    private static ScxSocketFrame createPingFrame() {
        var pingFrame = new ScxSocketFrame();
        pingFrame.type = PING;
        return pingFrame;
    }

    private static ScxSocketFrame createPongFrame() {
        var pongFrame = new ScxSocketFrame();
        pongFrame.type = PONG;
        return pongFrame;
    }

    public static ScxSocketFrame createAckFrame(long ack_id) {
        var ackFrame = new ScxSocketFrame();
        ackFrame.type = ACK;
        ackFrame.ack_id = ack_id;
        return ackFrame;
    }

    public static ScxSocketFrame createAckFrame(long ack_id, String payload) {
        var ackFrame = createAckFrame(ack_id);
        ackFrame.payload = payload;
        return ackFrame;
    }

    private ScxSocketFrame createBaseFrame(String content, SendOptions options) {
        var baseFrame = new ScxSocketFrame();
        baseFrame.seq_id = this.seqID.getAndIncrement();
        baseFrame.now = System.currentTimeMillis();
        baseFrame.need_ack = options.getNeedAck();
        baseFrame.payload = content;
        return baseFrame;
    }

    public ScxSocketFrame createMessageFrame(String content, SendOptions options) {
        var messageFrame = createBaseFrame(content, options);
        messageFrame.type = MESSAGE;
        return messageFrame;
    }

    public ScxSocketFrame createEventFrame(String eventName, String payload, SendOptions options) {
        var eventFrame = createMessageFrame(payload, options);
        eventFrame.event_name = eventName;
        return eventFrame;
    }

    public ScxSocketFrame createRequestFrame(String eventName, String payload, SendOptions options) {
        var requestFrame = createEventFrame(eventName, payload, options);
        requestFrame.need_response = true;
        return requestFrame;
    }

    public ScxSocketFrame createResponseFrame(long ack_id, String payload, SendOptions options) {
        var responseFrame = createBaseFrame(payload, options);
        responseFrame.type = RESPONSE;
        responseFrame.ack_id = ack_id;
        return responseFrame;
    }

}
